# USR-R16 Python Client

## Description:
A Python client to communicate with the [USR-R16 16x relay switches module](https://www.zhize.com.cn/wangluojidianqi/16luwangluojidianqi.html)

### Install package:
```bash
pip install usr-r16
```

### Usage:
see test.py